@@ -46,6 +46,7 @@ QUALIFIERS = {
         "mol_type": "mol_type",
         "Is_circular": "is_circular",
         "transl_table": "transl_table",
+        "Name": "name",
     },
 }
 SO_IDS = {
@@ -215,6 +216,11 @@ def _get_rna_features(record, mol_type):
         rna_model["location"] = make_location(
             sorted(exon_positions)[0], sorted(exon_positions)[-1]
         )
+    else:
+        rna_model["location"] = make_location(
+            record.annotations["sequence-region"][0][1],
+            record.annotations["sequence-region"][0][2],
+        )
     rna_model["features"] = features[0]["features"]
     features[0]["features"] = [rna_model]
     return features
@@ -253,11 +259,13 @@ def _create_record_model(record, source=None):
             record.annotations["sequence-region"][0][2],
         ),
     }
-    if mol_type:
-        model["qualifiers"] = {"mol_type": mol_type}
+
+    if region_model and region_model.get("qualifiers"):
+        model["qualifiers"] = region_model["qualifiers"]
 
     if features:
         model["features"] = features
+
     return model
 
 
